@@ -21,17 +21,27 @@
 #define _FASTDDS_DOMAIN_PARTICIPANT_HPP_
 
 #include <fastdds/dds/topic/TypeSupport.hpp>
+#include <fastdds/dds/topic/Topic.hpp>
 #include <fastrtps/types/TypeIdentifier.h>
 
 #include <fastdds/rtps/common/Guid.h>
 #include <fastdds/rtps/common/SampleIdentity.h>
 #include <fastdds/rtps/attributes/RTPSParticipantAttributes.h>
 #include <fastrtps/types/TypesBase.h>
+#include <fastdds/dds/core/status/StatusMask.hpp>
+#include <fastdds/dds/core/Entity.hpp>
+#include <fastdds/dds/domain/qos/DomainParticipantQos.hpp>
 
 #include <utility>
 
 using eprosima::fastrtps::types::ReturnCode_t;
 
+namespace dds {
+namespace domain {
+class DomainParticipant;
+}
+}
+
 namespace eprosima {
 namespace fastrtps {
 namespace rtps {
@@ -59,131 +69,242 @@ class PublisherListener;
 class Subscriber;
 class SubscriberQos;
 class SubscriberListener;
+class TopicQos;
 
 /**
  * Class DomainParticipant used to group Publishers and Subscribers into a single working unit.
  * @ingroup FASTDDS_MODULE
  */
-class RTPS_DllAPI DomainParticipant
+class DomainParticipant : public Entity
 {
 public:
 
+    /**
+     * This operation returns the value of the DomainParticipant QoS policies
+     * @param qos DomainParticipantQos reference where the qos is going to be returned
+     * @return RETCODE_OK
+     */
+    RTPS_DllAPI ReturnCode_t get_qos(
+            DomainParticipantQos& qos) const;
+
+    /**
+     * @brief This operation returns the value of the DomainParticipant QoS policies
+     * @return A reference to the DomainParticipantQos
+     */
+    RTPS_DllAPI const DomainParticipantQos& get_qos() const;
+
+    /**
+     * @brief This operation enables the DomainParticipant
+     * @return RETCODE_OK
+     */
+    RTPS_DllAPI ReturnCode_t enable() override;
+
+    /**
+     * This operation sets the value of the DomainParticipant QoS policies.
+     * @param qos DomainParticipantQos to be set
+     * @return RETCODE_IMMUTABLE_POLICY if any of the Qos cannot be changed, RETCODE_INCONSISTENT_POLICY if the Qos is not
+     * self consistent and RETCODE_OK if the qos is changed correctly.
+     */
+    RTPS_DllAPI ReturnCode_t set_qos(
+            const DomainParticipantQos& qos) const;
+
     /**
      * Allows modifying the DomainParticipantListener.
      * @param listener
-     * @return true if the listener was updated.
+     * @return RETCODE_OK
      */
-    ReturnCode_t set_listener(
+    RTPS_DllAPI ReturnCode_t set_listener(
             DomainParticipantListener* listener);
 
     /**
      * Allows accessing the DomainParticipantListener.
-     * @return DomainParticipantListener
+     * @return DomainParticipantListener pointer
      */
-    const DomainParticipantListener* get_listener() const;
+    RTPS_DllAPI const DomainParticipantListener* get_listener() const;
 
     /**
      * Create a Publisher in this Participant.
      * @param qos QoS of the Publisher.
-     * @param att Attributes of the Publisher. TopicAttributes and WriterQos will be ignored using DDS interface.
-     * @param listen Pointer to the listener.
+     * @param listener Pointer to the listener (default: nullptr)
+     * @param mask StatusMask that holds statuses the listener responds to (default: all)
      * @return Pointer to the created Publisher.
      */
-    Publisher* create_publisher(
-            const fastdds::dds::PublisherQos& qos,
-            const fastrtps::PublisherAttributes& att,
-            PublisherListener* listen = nullptr);
+    RTPS_DllAPI Publisher* create_publisher(
+            const PublisherQos& qos,
+            PublisherListener* listener = nullptr,
+            const StatusMask& mask = StatusMask::all());
+
+    /**
+     * Create a Publisher in this Participant.
+     * @param profile_name Publisher profile name.
+     * @param listener Pointer to the listener (default: nullptr)
+     * @param mask StatusMask that holds statuses the listener responds to (default: all)
+     * @return Pointer to the created Publisher.
+     */
+    RTPS_DllAPI Publisher* create_publisher_with_profile(
+            const std::string& profile_name,
+            PublisherListener* listener = nullptr,
+            const StatusMask& mask = StatusMask::all());
 
     /**
      * Deletes an existing Publisher.
      * @param publisher to be deleted.
-     * @return if publisher was deleted.
+     * @return RETCODE_PRECONDITION_NOT_MET if the publisher does not belong to this participant or if it has active DataWriters,
+     * RETCODE_OK if it is correctly deleted and RETCODE_ERROR otherwise.
      */
-    ReturnCode_t delete_publisher(
+    RTPS_DllAPI ReturnCode_t delete_publisher(
             Publisher* publisher);
 
     /**
      * Create a Subscriber in this Participant.
      * @param qos QoS of the Subscriber.
-     * @param att Attributes of the Subscriber. TopicAttributes and ReaderQos will be ignored using DDS interface.
-     * @param listen Pointer to the listener.
+     * @param listener Pointer to the listener (default: nullptr)
+     * @param mask StatusMask that holds statuses the listener responds to (default: all)
      * @return Pointer to the created Subscriber.
      */
-    Subscriber* create_subscriber(
-            const fastdds::dds::SubscriberQos& qos,
-            const fastrtps::SubscriberAttributes& att,
-            SubscriberListener* listen = nullptr);
+    RTPS_DllAPI Subscriber* create_subscriber(
+            const SubscriberQos& qos,
+            SubscriberListener* listener = nullptr,
+            const StatusMask& mask = StatusMask::all());
+
+    /**
+     * Create a Subscriber in this Participant.
+     * @param profile_name Subscriber profile name.
+     * @param listener Pointer to the listener (default: nullptr)
+     * @param mask StatusMask that holds statuses the listener responds to (default: all)
+     * @return Pointer to the created Subscriber.
+     */
+    RTPS_DllAPI Subscriber* create_subscriber_with_profile(
+            const std::string& profile_name,
+            SubscriberListener* listener = nullptr,
+            const StatusMask& mask = StatusMask::all());
 
     /**
      * Deletes an existing Subscriber.
      * @param subscriber to be deleted.
-     * @return if subscriber was deleted.
+     * @return RETCODE_PRECONDITION_NOT_MET if the subscriber does not belong to this participant or if it has active DataReaders,
+     * RETCODE_OK if it is correctly deleted and RETCODE_ERROR otherwise.
      */
-    ReturnCode_t delete_subscriber(
+    RTPS_DllAPI ReturnCode_t delete_subscriber(
             Subscriber* subscriber);
 
     /**
      * Register a type in this participant.
      * @param type TypeSupport.
      * @param type_name The name that will be used to identify the Type.
-     * @return True if registered.
+     * @return RETCODE_BAD_PARAMETER if the size of the name is 0, RERCODE_PRECONDITION_NOT_MET if there is another TypeSupport
+     * with the same name and RETCODE_OK if it is correctly registered.
      */
-    bool register_type(
+    RTPS_DllAPI ReturnCode_t register_type(
             TypeSupport type,
             const std::string& type_name);
 
     /**
      * Register a type in this participant.
      * @param type TypeSupport.
-     * @return True if registered.
+     * @return RETCODE_BAD_PARAMETER if the size of the name is 0, RERCODE_PRECONDITION_NOT_MET if there is another TypeSupport
+     * with the same name and RETCODE_OK if it is correctly registered.
      */
-    bool register_type(
+    RTPS_DllAPI ReturnCode_t register_type(
             TypeSupport type);
 
     /**
      * Unregister a type in this participant.
      * @param typeName Name of the type
-     * @return True if unregistered.
+     * @return RETCODE_BAD_PARAMETER if the size of the name is 0, RERCODE_PRECONDITION_NOT_MET if there are entities using that
+     * TypeSupport and RETCODE_OK if it is correctly unregistered.
      */
-    bool unregister_type(
-            const char* typeName);
+    RTPS_DllAPI ReturnCode_t unregister_type(
+            const std::string& typeName);
 
-    // TODO create/delete topic
+    /**
+     * Create a Topic in this Participant.
+     * @param topic_name Name of the Topic.
+     * @param type_name Data type of the Topic.
+     * @param qos QoS of the Topic.
+     * @param listener Pointer to the listener (default: nullptr)
+     * @param mask StatusMask that holds statuses the listener responds to (default: all)
+     * @return Pointer to the created Topic.
+     */
+    RTPS_DllAPI Topic* create_topic(
+            const std::string& topic_name,
+            const std::string& type_name,
+            const TopicQos& qos,
+            TopicListener* listener = nullptr,
+            const StatusMask& mask = StatusMask::all());
+
+    /**
+     * Create a Topic in this Participant.
+     * @param topic_name Name of the Topic.
+     * @param type_name Data type of the Topic.
+     * @param profile_name Topic profile name.
+     * @param listener Pointer to the listener (default: nullptr)
+     * @param mask StatusMask that holds statuses the listener responds to (default: all)
+     * @return Pointer to the created Topic.
+     */
+    RTPS_DllAPI Topic* create_topic_with_profile(
+            const std::string& topic_name,
+            const std::string& type_name,
+            const std::string& profile_name,
+            TopicListener* listener = nullptr,
+            const StatusMask& mask = StatusMask::all());
+
+    /**
+     * Deletes an existing Topic.
+     * @param topic to be deleted.
+     * @return RETCODE_BAD_PARAMETER if the topic passed is a nullptr, RETCODE_PRECONDITION_NOT_MET if the topic does not belong to
+     * this participant or if it is referenced by any entity and ETCODE_OK if the Topic was deleted.
+     */
+    RTPS_DllAPI ReturnCode_t delete_topic(
+            Topic* topic);
+
+    /**
+     * Looks up an existing, locally created @ref TopicDescription, based on its name.
+     * May be called on a disabled participant.
+     *
+     * @param topic_name Name of the @ref TopicDescription to search for.
+     *
+     * @return Pointer to the topic description, if it has been created locally. Otherwise, nullptr is returned.
+     *
+     * @remark UNSAFE. It is unsafe to lookup a topic description while another thread is creating a topic.
+     */
+    RTPS_DllAPI TopicDescription* lookup_topicdescription(
+            const std::string& topic_name) const;
 
     /* TODO
-    Subscriber* get_builtin_subscriber();
-    */
+       Subscriber* get_builtin_subscriber();
+     */
 
     /* TODO
-    bool ignore_participant(
+       bool ignore_participant(
             const fastrtps::rtps::InstanceHandle_t& handle);
-    */
+     */
 
     /* TODO
-    bool ignore_topic(
+       bool ignore_topic(
             const fastrtps::rtps::InstanceHandle_t& handle);
-    */
+     */
 
     /* TODO
-    bool ignore_publication(
+       bool ignore_publication(
             const fastrtps::rtps::InstanceHandle_t& handle);
-    */
+     */
 
     /* TODO
-    bool ignore_subscription(
+       bool ignore_subscription(
             const fastrtps::rtps::InstanceHandle_t& handle);
-    */
+     */
 
     /**
      * This operation retrieves the domain_id used to create the DomainParticipant.
      * The domain_id identifies the DDS domain to which the DomainParticipant belongs.
      * @return The Participant's domain_id
      */
-    uint8_t get_domain_id() const;
+    RTPS_DllAPI DomainId_t get_domain_id() const;
 
     /* TODO
-    bool delete_contained_entities();
-    */
+       bool delete_contained_entities();
+     */
 
     /**
      * This operation manually asserts the liveliness of the DomainParticipant.
@@ -194,12 +315,12 @@ public:
      * the LIVELINESS set to MANUAL_BY_PARTICIPANT and it only affects the liveliness of those DataWriter entities.
      * Otherwise, it has no effect.
      *
-     * NOTE: Writing data via the write operation on a DataWriter asserts liveliness on the DataWriter itself and its
+     * @note Writing data via the write operation on a DataWriter asserts liveliness on the DataWriter itself and its
      * DomainParticipant. Consequently the use of assert_liveliness is only needed if the application is not
      * writing data regularly.
-     * @return if liveliness was asserted.
+     * @return RETCODE_OK if the liveliness was asserted, RETCODE_ERROR otherwise.
      */
-    ReturnCode_t assert_liveliness();
+    RTPS_DllAPI ReturnCode_t assert_liveliness();
 
     /**
      * This operation sets a default value of the Publisher QoS policies which will be used for newly created
@@ -211,11 +332,11 @@ public:
      * The special value PUBLISHER_QOS_DEFAULT may be passed to this operation to indicate that the default QoS
      * should be reset back to the initial values the factory would use, that is the values that would be used
      * if the set_default_publisher_qos operation had never been called.
-     * @param qos
-     * @return if given qos was applied as default.
+     * @param qos PublisherQos to be set
+     * @return RETCODE_INCONSISTENT_POLICY if the Qos is not self consistent and RETCODE_OK if the qos is changed correctly.
      */
-    ReturnCode_t set_default_publisher_qos(
-            const fastdds::dds::PublisherQos& qos);
+    RTPS_DllAPI ReturnCode_t set_default_publisher_qos(
+            const PublisherQos& qos);
 
     /**
      * This operation retrieves the default value of the Publisher QoS, that is, the QoS policies which will be used
@@ -226,7 +347,7 @@ public:
      * call to set_default_publisher_qos, or else, if the call was never made, the default values.
      * @return Current default publisher qos.
      */
-    const fastdds::dds::PublisherQos& get_default_publisher_qos() const;
+    RTPS_DllAPI const PublisherQos& get_default_publisher_qos() const;
 
     /**
      * This operation retrieves the default value of the Publisher QoS, that is, the QoS policies which will be used
@@ -235,11 +356,11 @@ public:
      *
      * The values retrieved get_default_publisher_qos will match the set of values specified on the last successful
      * call to set_default_publisher_qos, or else, if the call was never made, the default values.
-     * @param qos
-     * @return Always true.
+     * @param qos PublisherQos reference where the default_publisher_qos is returned
+     * @return RETCODE_OK
      */
-    ReturnCode_t get_default_publisher_qos(
-            fastdds::dds::PublisherQos& qos) const;
+    RTPS_DllAPI ReturnCode_t get_default_publisher_qos(
+            PublisherQos& qos) const;
 
     /**
      * This operation sets a default value of the Subscriber QoS policies that will be used for newly created
@@ -251,11 +372,11 @@ public:
      * The special value SUBSCRIBER_QOS_DEFAULT may be passed to this operation to indicate that the default QoS
      * should be reset back to the initial values the factory would use, that is the values that would be used
      * if the set_default_subscriber_qos operation had never been called.
-     * @param qos
-     * @return if given qos was applied as default.
+     * @param qos SubscriberQos to be set
+     * @return RETCODE_INCONSISTENT_POLICY if the Qos is not self consistent and RETCODE_OK if the qos is changed correctly.
      */
-    ReturnCode_t set_default_subscriber_qos(
-            const fastdds::dds::SubscriberQos& qos);
+    RTPS_DllAPI ReturnCode_t set_default_subscriber_qos(
+            const SubscriberQos& qos);
 
     /**
      * This operation retrieves the default value of the Subscriber QoS, that is, the QoS policies which will be used
@@ -266,7 +387,7 @@ public:
      * call to set_default_subscriber_qos, or else, if the call was never made, the default values.
      * @return Current default subscriber qos.
      */
-    const fastdds::dds::SubscriberQos& get_default_subscriber_qos() const;
+    RTPS_DllAPI const SubscriberQos& get_default_subscriber_qos() const;
 
     /**
      * This operation retrieves the default value of the Subscriber QoS, that is, the QoS policies which will be used
@@ -275,35 +396,74 @@ public:
      *
      * The values retrieved get_default_subscriber_qos will match the set of values specified on the last successful
      * call to set_default_subscriber_qos, or else, if the call was never made, the default values.
-     * @param qos
-     * @return Always true.
+     * @param qos SubscriberQos reference where the default_subscriber_qos is returned
+     * @return RETCODE_OK
      */
-    ReturnCode_t get_default_subscriber_qos(
-            fastdds::dds::SubscriberQos& qos) const;
+    RTPS_DllAPI ReturnCode_t get_default_subscriber_qos(
+            SubscriberQos& qos) const;
 
-    // TODO Get/Set default Topic Qos
+
+    /**
+     * This operation sets a default value of the Topic QoS policies which will be used for newly created
+     * Topic entities in the case where the QoS policies are defaulted in the create_topic operation.
+     *
+     * This operation will check that the resulting policies are self consistent; if they are not, the operation
+     * will have no effect and return INCONSISTENT_POLICY.
+     *
+     * The special value TOPIC_QOS_DEFAULT may be passed to this operation to indicate that the default QoS
+     * should be reset back to the initial values the factory would use, that is the values that would be used
+     * if the set_default_topic_qos operation had never been called.
+     * @param qos TopicQos to be set
+     * @return RETCODE_INCONSISTENT_POLICY if the Qos is not self consistent and RETCODE_OK if the qos is changed correctly.
+     */
+    RTPS_DllAPI ReturnCode_t set_default_topic_qos(
+            const TopicQos& qos);
+
+    /**
+     * This operation retrieves the default value of the Topic QoS, that is, the QoS policies that will be used
+     * for newly created Topic entities in the case where the QoS policies are defaulted in the create_topic
+     * operation.
+     *
+     * The values retrieved get_default_topic_qos will match the set of values specified on the last successful
+     * call to set_default_topic_qos, or else, TOPIC_QOS_DEFAULT if the call was never made.
+     * @return Current default topic qos.
+     */
+    RTPS_DllAPI const TopicQos& get_default_topic_qos() const;
+
+    /**
+     * This operation retrieves the default value of the Topic QoS, that is, the QoS policies that will be used
+     * for newly created Topic entities in the case where the QoS policies are defaulted in the create_topic
+     * operation.
+     *
+     * The values retrieved get_default_topic_qos will match the set of values specified on the last successful
+     * call to set_default_topic_qos, or else, TOPIC_QOS_DEFAULT if the call was never made.
+     * @param qos TopicQos reference where the default_topic_qos is returned
+     * @return RETCODE_OK
+     */
+    RTPS_DllAPI ReturnCode_t get_default_topic_qos(
+            TopicQos& qos) const;
 
     /* TODO
-    bool get_discovered_participants(
+       bool get_discovered_participants(
             std::vector<fastrtps::rtps::InstanceHandle_t>& participant_handles) const;
-    */
+     */
 
     /* TODO
-    bool get_discovered_participant_data(
+       bool get_discovered_participant_data(
             ParticipantBuiltinTopicData& participant_data,
             const fastrtps::rtps::InstanceHandle_t& participant_handle) const;
-    */
+     */
 
     /* TODO
-    bool get_discovered_topics(
+       bool get_discovered_topics(
             std::vector<fastrtps::rtps::InstanceHandle_t>& topic_handles) const;
-    */
+     */
 
     /* TODO
-    bool get_discovered_topic_data(
+       bool get_discovered_topic_data(
             TopicBuiltinTopicData& topic_data,
             const fastrtps::rtps::InstanceHandle_t& topic_handle) const;
-    */
+     */
 
     /**
      * This operation checks whether or not the given handle represents an Entity that was created from the
@@ -311,50 +471,52 @@ public:
      * @param handle InstanceHandle of the entity to look for.
      * @param recursive The containment applies recursively. That is, it applies both to entities
      * (TopicDescription, Publisher, or Subscriber) created directly using the DomainParticipant as well as
-     * entities created using a contained Publisher, or Subscriber as the factory, and so forth.
+     * entities created using a contained Publisher, or Subscriber as the factory, and so forth. (default: true)
      * @return True if entity is contained. False otherwise.
      */
-    bool contains_entity(
+    RTPS_DllAPI bool contains_entity(
             const fastrtps::rtps::InstanceHandle_t& handle,
             bool recursive = true) const;
 
     /**
      * This operation returns the current value of the time that the service uses to time-stamp data-writes
      * and to set the reception-timestamp for the data-updates it receives.
-     * @param current_time
-     * @return Always true
+     * @param current_time Time_t reference where the current time is returned
+     * @return RETCODE_OK
      */
-    ReturnCode_t get_current_time(
+    RTPS_DllAPI ReturnCode_t get_current_time(
             fastrtps::Time_t& current_time) const;
 
     /**
      * This method gives access to a registered type based on its name.
-     * @param type_name
-     * @return TypeSupport
+     * @param type_name Name of the type
+     * @return TypeSupport corresponding to the type_name
      */
-    TypeSupport find_type(
+    RTPS_DllAPI TypeSupport find_type(
             const std::string& type_name) const;
 
     /**
      * Returns the DomainParticipant's handle.
      * @return InstanceHandle of this DomainParticipant.
      */
-    const fastrtps::rtps::InstanceHandle_t& get_instance_handle() const;
+    RTPS_DllAPI const fastrtps::rtps::InstanceHandle_t& get_instance_handle() const;
 
     // From here legacy RTPS methods.
 
-    const fastrtps::rtps::GUID_t& guid() const;
-
     /**
-     * Get the participant attributes
-     * @return Participant attributes
+     * @brief Getter for the Participant GUID
+     * @return A reference to the GUID
      */
-    const fastrtps::ParticipantAttributes& get_attributes() const;
-
-    std::vector<std::string> get_participant_names() const;
+    RTPS_DllAPI const fastrtps::rtps::GUID_t& guid() const;
 
     /**
-     * This method can be used when using a StaticEndpointDiscovery mechanism differnet that the one
+     * @brief Getter for the participant names
+     * @return Vector with the names
+     */
+    RTPS_DllAPI std::vector<std::string> get_participant_names() const;
+
+    /**
+     * This method can be used when using a StaticEndpointDiscovery mechanism different that the one
      * included in FastRTPS, for example when communicating with other implementations.
      * It indicates the Participant that an Endpoint from the XML has been discovered and
      * should be activated.
@@ -363,32 +525,34 @@ public:
      * @param kind EndpointKind (WRITER or READER)
      * @return True if correctly found and activated.
      */
-    bool new_remote_endpoint_discovered(
+    RTPS_DllAPI bool new_remote_endpoint_discovered(
             const fastrtps::rtps::GUID_t& partguid,
             uint16_t userId,
             fastrtps::rtps::EndpointKind_t kind);
 
-    fastrtps::rtps::ResourceEvent& get_resource_event() const;
+    /**
+     * @brief Getter for the resource event
+     * @return A reference to the resource event
+     */
+    RTPS_DllAPI fastrtps::rtps::ResourceEvent& get_resource_event() const;
 
     /**
      * When a DomainParticipant receives an incomplete list of TypeIdentifiers in a
      * PublicationBuiltinTopicData or SubscriptionBuiltinTopicData, it may request the additional type
      * dependencies by invoking the getTypeDependencies operation.
-     * @param in
-     * @param out
-     * @return
+     * @param in TypeIdentifier sequence
+     * @return SampleIdentity
      */
-    fastrtps::rtps::SampleIdentity get_type_dependencies(
+    RTPS_DllAPI fastrtps::rtps::SampleIdentity get_type_dependencies(
             const fastrtps::types::TypeIdentifierSeq& in) const;
 
     /**
      * A DomainParticipant may invoke the operation getTypes to retrieve the TypeObjects associated with a
      * list of TypeIdentifiers.
-     * @param in
-     * @param out
-     * @return
+     * @param in TypeIdentifier sequence
+     * @return SampleIdentity
      */
-    fastrtps::rtps::SampleIdentity get_types(
+    RTPS_DllAPI fastrtps::rtps::SampleIdentity get_types(
             const fastrtps::types::TypeIdentifierSeq& in) const;
 
     /**
@@ -397,7 +561,7 @@ public:
      * The registration will be perform asynchronously and the user will be notified through the
      * given callback, which receives the type_name as unique argument.
      * If the type is already registered, the function will return true, but the callback will not be called.
-     * If the given type_information is enought to build the type without using the typelookup service,
+     * If the given type_information is enough to build the type without using the typelookup service,
      * it will return true and the callback will be never called.
      * @param type_information
      * @param type_name
@@ -405,22 +569,40 @@ public:
      * @return true if type is already available (callback will not be called). false if type isn't available yet
      * (the callback will be called if negotiation is success, and ignored in other case).
      */
-    bool register_remote_type(
+    RTPS_DllAPI ReturnCode_t register_remote_type(
             const fastrtps::types::TypeInformation& type_information,
             const std::string& type_name,
             std::function<void(const std::string& name, const fastrtps::types::DynamicType_ptr type)>& callback);
 
+    /**
+     * @brief Destructor
+     */
+    RTPS_DllAPI virtual ~DomainParticipant();
+
+    /**
+     * @brief Check if the Participant has any Publisher, Subscriber or Topic
+     * @return true if any, false otherwise.
+     */
+    bool has_active_entities();
+
 private:
 
-    DomainParticipant();
+    RTPS_DllAPI DomainParticipant(
+            const StatusMask& mask = StatusMask::all());
 
-    virtual ~DomainParticipant();
+    RTPS_DllAPI DomainParticipant(
+            DomainId_t domain_id,
+            const DomainParticipantQos& qos,
+            DomainParticipantListener* listener,
+            const StatusMask& mask = StatusMask::all());
 
     DomainParticipantImpl* impl_;
 
     friend class DomainParticipantFactory;
 
     friend class DomainParticipantImpl;
+
+    friend class ::dds::domain::DomainParticipant;
 };
 
 } // namespace dds
